@@ -21,6 +21,7 @@ extern "C" {
 
 /* Library modules */
 #include "re_aes.h"
+#include "re_async.h"
 #include "re_base64.h"
 #include "re_bfcp.h"
 #include "re_btrace.h"
@@ -44,6 +45,7 @@ extern "C" {
 #include "re_json.h"
 #include "re_rtmp.h"
 #include "re_rtp.h"
+#include "re_rtpext.h"
 #include "re_sdp.h"
 #include "re_uri.h"
 #include "re_sip.h"
@@ -61,6 +63,7 @@ extern "C" {
 #include "re_tls.h"
 #include "re_turn.h"
 #include "re_udp.h"
+#include "re_unixsock.h"
 #include "re_websock.h"
 #include "re_shim.h"
 #include "re_trice.h"
