@@ -15,11 +15,13 @@ void hash_unlink(struct le *le);
 struct le *hash_lookup(const struct hash *h, uint32_t key, list_apply_h *ah,
 		       void *arg);
 struct le *hash_apply(const struct hash *h, list_apply_h *ah, void *arg);
+struct list *hash_list_idx(const struct hash *h, uint32_t i);
 struct list *hash_list(const struct hash *h, uint32_t key);
 uint32_t hash_bsize(const struct hash *h);
 void hash_flush(struct hash *h);
 void hash_clear(struct hash *h);
 uint32_t hash_valid_size(uint32_t size);
+int hash_debug(struct re_printf *pf, struct hash *h);
 
 
 /* Hash functions */
