@@ -16,7 +16,6 @@
 #include <arpa/inet.h>
 #endif
 
-
 /** Length of IPv4 address string */
 #ifndef INET_ADDRSTRLEN
 #define INET_ADDRSTRLEN 16
@@ -39,8 +38,7 @@ struct sa;
 
 
 /* Net generic */
-int  net_hostaddr(int af, struct sa *ip);
-int  net_dst_source_addr_get(struct sa *dst, struct sa *ip);
+int  net_dst_source_addr_get(const struct sa *dst, struct sa *ip);
 int  net_default_source_addr_get(int af, struct sa *ip);
 int  net_default_gateway_get(int af, struct sa *gw);
 
@@ -51,8 +49,8 @@ void net_sock_close(void);
 
 
 /* Net socket options */
-int net_sockopt_blocking_set(int fd, bool blocking);
-int net_sockopt_reuse_set(int fd, bool reuse);
+int net_sockopt_blocking_set(re_sock_t fd, bool blocking);
+int net_sockopt_reuse_set(re_sock_t fd, bool reuse);
 
 
 /* Net interface (if.c) */
@@ -106,3 +104,4 @@ int net_rt_debug(struct re_printf *pf, void *unused);
 /* Net strings */
 const char *net_proto2name(int proto);
 const char *net_af2name(int af);
+
