@@ -250,6 +250,13 @@ struct sip_conncfg {
 	uint16_t srcport;
 };
 
+/** SIP UAS Authentication */
+struct sip_uas_auth {
+	const char *realm;
+	char *nonce;
+	bool stale;
+};
+
 struct sip;
 struct sip_lsnr;
 struct sip_request;
@@ -257,12 +264,15 @@ struct sip_strans;
 struct sip_auth;
 struct sip_dialog;
 struct sip_keepalive;
+struct sip_uas_auth;
 struct dnsc;
 
 typedef bool(sip_msg_h)(const struct sip_msg *msg, void *arg);
 typedef int(sip_send_h)(enum sip_transp tp, struct sa *src,
 			const struct sa *dst, struct mbuf *mb,
 			struct mbuf **contp, void *arg);
+typedef int(sip_conn_h)(struct sa *src, const struct sa *dst, struct mbuf *mb,
+			void *arg);
 typedef void(sip_resp_h)(int err, const struct sip_msg *msg, void *arg);
 typedef void(sip_cancel_h)(void *arg);
 typedef void(sip_exit_h)(void *arg);
@@ -276,6 +286,8 @@ typedef void(sip_keepalive_h)(int err, void *arg);
 typedef void(sip_trace_h)(bool tx, enum sip_transp tp,
 			  const struct sa *src, const struct sa *dst,
 			  const uint8_t *pkt, size_t len, void *arg);
+typedef int (sip_uas_auth_h)(uint8_t *ha1, const struct pl *user,
+			     const char *realm, void *arg);
 
 
 /* sip */
@@ -288,6 +300,9 @@ int  sip_listen(struct sip_lsnr **lsnrp, struct sip *sip, bool req,
 int  sip_debug(struct re_printf *pf, const struct sip *sip);
 int  sip_send(struct sip *sip, void *sock, enum sip_transp tp,
 	      const struct sa *dst, struct mbuf *mb);
+int  sip_send_conn(struct sip *sip, void *sock, enum sip_transp tp,
+		   const struct sa *dst, struct mbuf *mb,
+		   sip_conn_h *connh, void *arg);
 void sip_set_trace_handler(struct sip *sip, sip_trace_h *traceh);
 
 
@@ -423,4 +438,13 @@ int sip_keepalive_start(struct sip_keepalive **kap, struct sip *sip,
 
 /* sip_conncfg */
 int sip_conncfg_set(struct sip *sip, const struct sa *paddr,
-		    const struct sip_conncfg conncfg);
+		    const struct sip_conncfg *conncfg);
+
+
+/* sip_uas_auth */
+int sip_uas_auth_gen(struct sip_uas_auth **authp, const struct sip_msg *msg,
+		     const char *realm);
+int sip_uas_auth_print(struct re_printf *pf,
+		       const struct sip_uas_auth *auth);
+int sip_uas_auth_check(struct sip_uas_auth *auth, const struct sip_msg *msg,
+		       sip_uas_auth_h *authh, void *arg);
